abacusai.problem_type — AbacusAI documentation

# `abacusai.problem_type`

## Module Contents

### Classes

`ProblemType` | Description of a problem type which is the common underlying problem for different use cases.

class abacusai.problem_type.ProblemType(client, problemType=None, requiredFeatureGroupType=None, optionalFeatureGroupTypes=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Description of a problem type which is the common underlying problem for different use cases.

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - problemType (str) –

    - requiredFeatureGroupType (str) – The required feature group types to train for this problem type

    - optionalFeatureGroupTypes (list of string) – The optional feature group types can be used to train for this problem type

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict